/********************************************************************
 FileName:     USBConfig.h
 Dependencies: Always: GenericTypeDefs.h, usbd.h
               Situational: hid.h, cdc.h, msd.h, etc.
 Processor:    PIC18 USB Microcontrollers
 Hardware:
 Complier:     Microchip C18
 Company:		Microchip Technology, Inc.

 Software License Agreement:

 The software supplied herewith by Microchip Technology Incorporated
 (the Company) for its PICmicro Microcontroller is intended and
 supplied to you, the Companys customer, for use solely and
 exclusively on Microchip PICmicro Microcontroller products. The
 software is owned by the Company and/or its supplier, and is
 protected under applicable copyright laws. All rights are reserved.
 Any use in violation of the foregoing restrictions may subject the
 user to criminal sanctions under applicable laws, as well as to
 civil liability for the breach of the terms and conditions of this
 license.

 THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************************
 File Description:

 Change History:
  Rev   Date         Description
  1.0   5/18/08       Modified for WinUSB (Jan Axelson)
  1.3   9/30/2008    Added USB_WINUSB_CONTROL_WRITE_HANDLER
 *******************************************************************/

/*********************************************************************
 * Descriptor specific type definitions are defined in: usbd.h
 ********************************************************************/

#ifndef USBCFG_H
#define USBCFG_H

/** INCLUDES *******************************************************/
// winusb.h must be included before usbcfg.h b/c usbcfg.h uses definitions from hid.h
// including hid.h here so that it can be auto-generated by a GUI tool.
#include "winusb.h"
#include "winusb_demo.h"

/** DEFINITIONS ****************************************************/
#define EP0_BUFF_SIZE           8   // 8, 16, 32, or 64
#define USB_MAX_NUM_INT             1   // For tracking Alternate Setting

#define WINUSB_INTERRUPT_EP 1
#define WINUSB_BULK_EP 2

#define USB_PING_PONG__NO_PING_PONG         0x00    //0b00
#define USB_PING_PONG__EP0_OUT_ONLY         0x01    //0b01
#define USB_PING_PONG__FULL_PING_PONG       0x02    //0b10
#define USB_PING_PONG__ALL_BUT_EP0          0x03    //0b11

#define USB_PING_PONG_MODE USB_PING_PONG__NO_PING_PONG
//#define USB_PING_PONG_MODE USB_PING_PONG__FULL_PING_PONG
//#define USB_PING_PONG_MODE USB_PING_PONG__EP0_OUT_ONLY

//NOTE: this is not supported in 18F4550 rev Ax
//#define USB_PING_PONG_MODE USB_PING_PONG__ALL_BUT_EP0

#define USB_EP0_BUFF_SIZE 8

#define USB_POLLING

#define USB_MAX_EP_NUMBER       2

/* Parameter definitions are defined in usbd.h */
#define MODE_PP                 USB_PING_PONG_MODE
#define UCFG_VAL                _PUEN|_TRINT|_FS|MODE_PP

//#define USE_SELF_POWER_SENSE_IO
//#define USE_USB_BUS_SENSE_IO

#define USE_USB_BOOTLOADER
#define SUPPORT_SET_DSC
#define SUPPORT_SYNC_FRAME

//#define USB_DYNAMIC_EP_CONFIG

/** DEVICE CLASS USAGE *********************************************/
#define USB_USE_WINUSB

#define USB_SUPPORT_DEVICE

/** ENDPOINTS ALLOCATION *******************************************/

#define WINUSB_BULK_IN_BYTES   			64
#define WINUSB_BULK_OUT_BYTES  			64
#define WINUSB_BULK_IN_EP_SIZE      	64
#define WINUSB_BULK_OUT_EP_SIZE     	64

#define WINUSB_CONTROL_IN_BYTES  	 	8
#define WINUSB_CONTROL_OUT_BYTES  	 	8

#define WINUSB_INTERRUPT_IN_BYTES    	2
#define WINUSB_INTERRUPT_OUT_BYTES   	2
#define WINUSB_INTERRUPT_IN_EP_SIZE     8
#define WINUSB_INTERRUPT_OUT_EP_SIZE    8

#define WINUSB_INTF_ID             		0x00
#define WINUSB_NUM_OF_DSC          		1

#define USB_WINUSB_CONTROL_WRITE_HANDLER HandleVendorControlWriteRequest

/** DEFINITIONS ****************************************************/

#endif //USBCFG_H
