/********************************************************************
 FileName:     usb_descriptors.c
 Dependencies: See INCLUDES section
 Processor:    PIC18 USB Microcontrollers
 Hardware:
 Complier:     Microchip C18
 Company:		Microchip Technology, Inc.

 Software License Agreement:

 The software supplied herewith by Microchip Technology Incorporated
 (the Company) for its PICmicro Microcontroller is intended and
 supplied to you, the Companys customer, for use solely and
 exclusively on Microchip PICmicro Microcontroller products. The
 software is owned by the Company and/or its supplier, and is
 protected under applicable copyright laws. All rights are reserved.
 Any use in violation of the foregoing restrictions may subject the
 user to criminal sanctions under applicable laws, as well as to
 civil liability for the breach of the terms and conditions of this
 license.

 THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************************
 File Description:

 Change History:
  Rev   Date         Description
  1.0   11/19/2004   Initial release
  2.1   02/26/2007   Updated for simplicity and to use common
                     coding style
        5/18/08      Modified for WinUSB. (Jan Axelson)
*******************************************************************/

/*********************************************************************
 * Descriptor specific type definitions are defined in: usbd.h
 * Configuration information is defined in: usbcfg.h
 ********************************************************************/

#ifndef __USB_DESCRIPTORS_C
#define __USB_DESCRIPTORS_C

/** INCLUDES *******************************************************/
#include "GenericTypeDefs.h"
#include "Compiler.h"
#include "usb_config.h"
#include "./USB/usb_device.h"

/** CONSTANTS ******************************************************/
#if defined(__18CXX)
#pragma romdata
#endif

/* Device Descriptor */
ROM USB_DEVICE_DESCRIPTOR device_dsc=
{
    0x12,    				// Size of this descriptor in bytes
    USB_DESCRIPTOR_DEVICE,  // DEVICE descriptor type
    0x0110,                 // USB Spec Release Number in BCD format
    0x00,                   // Class Code
    0x00,                   // Subclass code
    0x00,                   // Protocol code
    EP0_BUFF_SIZE,          // Max packet size for EP0, see usbcfg.h
    0x0925,                 // Vendor ID: Lakeview Research
    0x1456,                 // Product ID: WinUSB demo
    0x0001,                 // Device release number in BCD format
    0x01,                   // Manufacturer string index
    0x02,                   // Product string index
    0x00,                   // Device serial number string index
    0x01                    // Number of possible configurations
};

/* Configuration 1 Descriptor */
ROM BYTE configDescriptor1[]={
    /* Configuration Descriptor */
    0x09,//sizeof(USB_CFG_DSC),    	// Size of this descriptor in bytes
    USB_DESCRIPTOR_CONFIGURATION,  	// CONFIGURATION descriptor type
    0x2e,0x00,            			// Total length of data for this cfg
    1,                      		// Number of interfaces in this cfg
    1,                      		// Index value of this configuration
    0,                      		// Configuration string index
    _DEFAULT|_SELF,          		// Attributes, see usbd.h
    50,                     		// Max power consumption (2X mA)

    /* Interface Descriptor */
    0x09,							//sizeof(USB_INTF_DSC)
    USB_DESCRIPTOR_INTERFACE,       // INTERFACE descriptor type
    0,                      		// Interface Number
    0,                      		// Alternate Setting Number
    4,                      		// Number of endpoints in this intf
    0xFF,               			// Class code
    0,     							// Subclass code
    0,     							// Protocol code
    0,                      		// Interface string index


// Endpoint Descriptor 
    0x07,//sizeof(USB_EP_DSC)
    USB_DESCRIPTOR_ENDPOINT,    //Endpoint Descriptor
    _EP01_IN,                   //EndpointAddress
    _INT,                       //Attributes
    0x08, 0x00, 				//WINUSB_INTERRUPT_IN_EP_SIZE                  
    0x0A,                       //Interval

    // Endpoint Descriptor 
    0x07,//sizeof(USB_EP_DSC)
    USB_DESCRIPTOR_ENDPOINT,    //Endpoint Descriptor
    _EP01_OUT,                  //EndpointAddress
    _INT,                      	//Attributes
    0x08, 0x00, 				//WINUSB_INTERRUPT_OUT_EP_SIZE
    0x0A,                       //Interval

    // Endpoint Descriptor 
    0x07,						//sizeof(USB_EP_DSC)
    USB_DESCRIPTOR_ENDPOINT,    //Endpoint Descriptor
    _EP02_IN,                   //EndpointAddress
    _BULK,                      //Attributes
    0x40, 0x00, 				//WINUSB_BULK_IN_EP_SIZE
    0x00,                       //Interval

    // Endpoint Descriptor 
    0x07,						//sizeof(USB_EP_DSC)
    USB_DESCRIPTOR_ENDPOINT,    //Endpoint Descriptor
    _EP02_OUT,                  //EndpointAddress
    _BULK,                      //Attributes
    0x40, 0x00, 				//WINUSB_BULK_OUT_EP_SIZE
    0x00                        //Interval
};

//Language code string descriptor

ROM struct{BYTE bLength;BYTE bDscType;WORD string[1];}sd000={
sizeof(sd000),USB_DESCRIPTOR_STRING,{0x0409
}};

//Manufacturer string descriptor

ROM struct{BYTE bLength;BYTE bDscType;WORD string[17];}sd001={
sizeof(sd001),USB_DESCRIPTOR_STRING,
{'L','a','k','e','v','i','e','w',' ','R','e','s','e','a','r','c','h'
}};

//Product string descriptor
ROM struct{BYTE bLength;BYTE bDscType;WORD string[11];}sd002={
sizeof(sd002),USB_DESCRIPTOR_STRING,
{'W','i','n','U','S','B',' ','D','e','m','o'
}};

//Array of configuration descriptors
ROM BYTE *ROM USB_CD_Ptr[]=
{
    (ROM BYTE *ROM)&configDescriptor1
};

//Array of string descriptors
ROM BYTE *ROM USB_SD_Ptr[]=
{
    (ROM BYTE *ROM)&sd000,
    (ROM BYTE *ROM)&sd001,
    (ROM BYTE *ROM)&sd002
};

/** EOF usbdescriptors.c ***************************************************/

#endif
